==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPointHandleRepresentation2D.java <==
// java wrapper for vtkPointHandleRepresentation2D object
//

package vtk;
import vtk.*;

public class vtkPointHandleRepresentation2D extends vtkHandleRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCursorShape_2(vtkPolyData id0);
  public void SetCursorShape(vtkPolyData id0)
    { SetCursorShape_2(id0); }

  private native long GetCursorShape_3();
  public vtkPolyData GetCursorShape() {
    long temp = GetCursorShape_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisplayPosition_4(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_4(id0); }

  private native void SetProperty_5(vtkProperty2D id0);
  public void SetProperty(vtkProperty2D id0)
    { SetProperty_5(id0); }

  private native void SetSelectedProperty_6(vtkProperty2D id0);
  public void SetSelectedProperty(vtkProperty2D id0)
    { SetSelectedProperty_6(id0); }

  private native long GetProperty_7();
  public vtkProperty2D GetProperty() {
    long temp = GetProperty_7();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_8();
  public vtkProperty2D GetSelectedProperty() {
    long temp = GetSelectedProperty_8();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double[] GetBounds_9();
  public double[] GetBounds()
    { return GetBounds_9(); }

  private native void BuildRepresentation_10();
  public void BuildRepresentation()
    { BuildRepresentation_10(); }

  private native void StartWidgetInteraction_11(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_11(id0); }

  private native void WidgetInteraction_12(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_12(id0); }

  private native int ComputeInteractionState_13(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_13(id0,id1,id2); }

  private native void ShallowCopy_14(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_14(id0); }

  private native void DeepCopy_15(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_15(id0); }

  private native void GetActors2D_16(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native void Highlight_19(int id0);
  public void Highlight(int id0)
    { Highlight_19(id0); }

  private native void SetPointPlacer_20(vtkPointPlacer id0);
  public void SetPointPlacer(vtkPointPlacer id0)
    { SetPointPlacer_20(id0); }

  public vtkPointHandleRepresentation2D() { super(); }

  public vtkPointHandleRepresentation2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkPointHandleRepresentation2D.java <==
// java wrapper for vtkPointHandleRepresentation2D object
//

package vtk;
import vtk.*;

public class vtkPointHandleRepresentation2D extends vtkHandleRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCursorShape_2(vtkPolyData id0);
  public void SetCursorShape(vtkPolyData id0)
    { SetCursorShape_2(id0); }

  private native long GetCursorShape_3();
  public vtkPolyData GetCursorShape() {
    long temp = GetCursorShape_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisplayPosition_4(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_4(id0); }

  private native void SetProperty_5(vtkProperty2D id0);
  public void SetProperty(vtkProperty2D id0)
    { SetProperty_5(id0); }

  private native void SetSelectedProperty_6(vtkProperty2D id0);
  public void SetSelectedProperty(vtkProperty2D id0)
    { SetSelectedProperty_6(id0); }

  private native long GetProperty_7();
  public vtkProperty2D GetProperty() {
    long temp = GetProperty_7();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_8();
  public vtkProperty2D GetSelectedProperty() {
    long temp = GetSelectedProperty_8();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double[] GetBounds_9();
  public double[] GetBounds()
    { return GetBounds_9(); }

  private native void BuildRepresentation_10();
  public void BuildRepresentation()
    { BuildRepresentation_10(); }

  private native void StartWidgetInteraction_11(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_11(id0); }

  private native void WidgetInteraction_12(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_12(id0); }

  private native int ComputeInteractionState_13(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_13(id0,id1,id2); }

  private native void ShallowCopy_14(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_14(id0); }

  private native void DeepCopy_15(vtkProp id0);
  public void DeepCopy(vtkProp id0)
    { DeepCopy_15(id0); }

  private native void GetActors2D_16(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native void Highlight_19(int id0);
  public void Highlight(int id0)
    { Highlight_19(id0); }

  private native void SetPointPlacer_20(vtkPointPlacer id0);
  public void SetPointPlacer(vtkPointPlacer id0)
    { SetPointPlacer_20(id0); }

  public vtkPointHandleRepresentation2D() { super(); }

  public vtkPointHandleRepresentation2D(long id) { super(id); }
  public native long   VTKInit();

}
